
<h1 align="center">
  <br>
  Poker Online API on Python
  <br>
</h1>

<p align="center">
  <a href="https://discord.gg/AsYzxRfT6J"><img src="https://bit.ly/32neyjM"></a>
</p>

# Install
```
pip3 install pokeronline.py
```

# Import and Auth
```python
from pokeronline import pokeronline

PokerOnline = pokeronline.Client("access_token")
```

### [Telegram](https://t.me/zakovskiy)
